var languageNames = {
"en-US": "angleški (ZDA)",
"sq": "albanski",
"am": "amharski",
"ar": "arabski",
"ast": "asturijski",
"bn": "bengalski",
"bn-IN": "bengalski (Indija)",
"bs": "bosanski",
"bg": "bolgarski",
"ca": "katalonski",
"ca-valencia": "katalonski (valencijski)",
"zh-CN": "kitajski (poenostavljeni)",
"zh-TW": "kitajski (tradicionalni)",
"hr": "hrvaški",
"cs": "češki",
"da": "danski",
"nl": "nizozemski",
"dz": "džonkški",
"en-GB": "angleški (Združeno kraljestvo)",
"en-ZA": "angleški (Južna Afrika)",
"eo": "esperanto",
"et": "estonski",
"eu": "baskovski",
"fi": "finski",
"fr": "francoski",
"gl": "galicijski",
"ka": "gruzijski",
"de": "nemški",
"el": "grški",
"gu": "gudžaratski",
"he": "hebrejski",
"hi": "hindujski",
"hu": "madžarski",
"id": "indonezijski",
"is": "islandski",
"it": "italijanski",
"ja": "japonski",
"km": "kmerski",
"ko": "korejski",
"lo": "laoški",
"lv": "latvijski",
"lt": "litovski",
"mk": "makedonski",
"ne": "nepalski",
"nn": "norveški (ninorsk)",
"nb": "norveški (bokmal)",
"om": "oromski",
"pl": "poljski",
"pt": "portugalski",
"pt-BR": "portugalski (Brazilija)",
"ro": "romunski",
"ru": "ruski",
"sid": "sidamski",
"si": "sinhalski",
"sk": "slovaški",
"sl": "slovenski",
"dsb": "lužiško srbski, dolnji",
"hsb": "lužiško srbski, gornji",
"es": "španski",
"sv": "švedski",
"tg": "tadžiški",
"ta": "tamilski",
"bo": "tibetanski",
"tl": "Tagalog",
"tr": "turški",
"ug": "ujgurski",
"uk": "ukrajinski",
"vi": "vietnamski",
};
